# -*- coding: utf-8 -*-
import onmqtt
import time

# 自行替换
product_id=  '533618'# 产品ID
device_id = '966637746' # 设备ID
auth_info = '1' # 鉴权信息

client = onmqtt.onenet_mqtt(product_id,device_id, auth_info)

def get_temp():
    file = open("/sys/class/thermal/thermal_zone0/temp")
    temp = float(file.read()) / 1000
    file.close()
    temp = 67
    print ("CPU的温度值为: %.3f" %temp)
    return temp

while 1:
    temperature = 666
    print('test')
    client.qpublish("temp_cpu", temperature)
    print('test')
    time.sleep(5)


import paho.mqtt.client as mqtt
from datetime import datetime
import json
info = -1
def on_msg(client, userdata, msg):
    global info
    info = msg.payload.decode('utf8')
    print("getinfo:",info)
class onenet_mqtt(mqtt.Client):
    host = '183.230.40.39'  # mqtt.heclouds.com
    port = 6002

    def __init__(self, pid, did, auth) -> None:
        '''
        pid: Product ID，产品ID,
        did：Device ID， 设备ID,
        auth: auth_info, 鉴权信息
        keepalive: 心跳时间
        '''
        self.product_id = pid 
        self.device_id = did
        self.auth_info = auth
        self.info = -1
        super().__init__(did)
        super().username_pw_set(pid, password=auth)
        self.on_message = on_msg
    def connect_onenet(self):
        super().connect(self.host, self.port, keepalive=60)  # 心跳
        pass

    def __packdata(self, data):
        ''' 
        onenet mqtt 数据格式：数据类型x1 数据长度x2 数据内容
        '''
        jdata = json.dumps(data)
        jlen = len(jdata)
        arr = bytearray(jlen + 3)
        arr[0] = 1  # publish数据类型为json
        arr[1] = int(jlen / 256)  # json数据长度 高位字节
        arr[2] = jlen % 256  # json数据长度 低位字节
        arr[3:] = jdata.encode('utf-8')  # json数据
        return arr

    def ppublish(self,
                topic='$dp',
                payload=None,
                qos=0,
                retain=False,
                properties=None):
        '''
        这里的payload是一个字典
        '''
        payload = self.__packdata(payload)
        return super().publish(topic, payload, qos, retain, properties)

    def qpublish(self, key, value, qos=0):
        '''
        快速发布信息。
        '''
        values = {
            'datastreams': [{
                "id": key,
                "datapoints": [{
                    "at": datetime.now().isoformat(),
                    "value": value
                }]
            }]
        }
        payload = self.__packdata(values)
        return super().publish('$dp', payload, qos)
    def getinfo(self):
        global info
        return info


#!/usr/bin/env python
# coding=utf-8

from setuptools import setup, find_packages

setup(
    name='onmqtt',
    version=0.4,
    description=(
        'link to mqtt'
    ),
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    author='onlytao',
    author_email='onlytao970@gmail.com',
    maintainer='onlytao',
    maintainer_email='onlytao970@gmail.com',
    license='MIT License',
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/only-tao/onmqtt>',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
    install_requires=[
        'paho-mqtt'
    ]
)